%define _disable_ld_no_undefined 0

%define name	hdf5
%define major	6
%define major_hl	6
%define libname %mklibname hdf5_ %{major}
%define libname_hl %mklibname hdf5_hl %{major_hl}
%define develname %mklibname %{name} -d
%define version 1.8.5
%define release %mkrel 2

Summary:	HDF5 library
Name:		%{name}
Version:	%{version}
Release:	%{release}
License:	Distributable (see included COPYING)
Group:		System/Libraries
URL:		http://www.hdfgroup.org/HDF5/
Source0:	ftp://ftp.hdfgroup.org/HDF5/current/src/%{name}-%{version}.tar.bz2
Patch0:		%{name}-1.8.4-as-needed.patch
#Patch2:		%{name}-1.8.4-signal.patch
Patch5:		%{name}-1.8.3-scaleoffset.patch
Patch8:		%{name}-1.8.1-lib64.patch
Patch9:		%{name}-1.8.5-fix-str-fmt.patch
BuildRequires:	libjpeg-static-devel
BuildRequires:	openssl-devel
BuildRequires:	zlib-devel
BuildRequires:	krb5-devel
BuildRequires:	gcc-gfortran
Requires:	%{libname} = %{version}-%{release}
BuildRoot:	%{_tmppath}/%{name}-%{version}-root

%description
HDF5 is a library and file format for storing scientific data. It was
designed to address some of the limitations of the HDF 4.x library and to
address current and anticipated requirements of modern systems and
applications. HDF5 includes the following improvements.

   - A new file format designed to address some of the deficiencies of
     HDF4.x, particularly the need to store larger files and more
     objects per file.
   - A simpler, more comprehensive data model that includes only two
     basic structures: a multidimensional array of record structures,
     and a grouping structure.
   - A simpler, better-engineered library and API, with improved
     support for parallel i/o, threads, and other requirements imposed
     by modern systems and applications.

%package -n %{libname}
Summary:	HDF5 libraries
Group:		System/Libraries
Provides:	%{name} = %{version}-%{release}
Provides:	lib%{name} = %{version}-%{release}

%description -n %{libname}
This package contains the libraries needed to run programs dynamically
linked with hdf5 libraries.

%package -n %{libname_hl}
Summary:	HDF5 high level libraries
Group:		System/Libraries
Provides:	%{name} = %{version}-%{release}
Provides:	lib%{name}_hl = %{version}-%{release}
Conflicts:	%{mklibname hdf 5 0}

%description -n %{libname_hl}
This package contains the high level libraries needed to run programs dynamically
linked with hdf5 libraries.

%package -n %{develname}
Summary:	Static libraries and header files for hdf5 development
Group:		Development/C
Provides:	%{name}-devel = %{version}-%{release}
Requires:	%{libname} = %{version}
Requires:	%{libname_hl} = %{version}
Obsoletes:	%{mklibname -d hdf 5 0} < %{version}

%description -n %{develname}
This package provides static libraries and header files needed
for develop applications requiring the "hdf5" library.

%prep
%setup -qn %{name}-%{version}
%patch0 -p0
#%patch2 -p1
%patch5 -p1
%ifarch x86_64
%patch8 -p0
%endif
%patch9 -p0
find -name '*.[ch]' -o -name '*.f90' -exec chmod -x {} +

%build
find %{buildroot} -type f -size 0 -name Dependencies -print0 |xargs -0 rm -f
find %{buildroot} -type f -size 0 -name .depend -print0 |xargs -0 rm -f

OPT_FLAGS="%{optflags} -O1 -Wno-long-long -Wfloat-equal -Wmissing-format-attribute -Wpadded"
%ifarch %{ix86} x86_64
OPT_FLAGS="$OPT_FLAGS -mieee-fp"
%endif

# (gb) 1.4.2-2mdk: "2.96" still deficient wrt. C++ exception handling on ia32
%ifarch %ix86
OPT_FLAGS=`echo "$OPT_FLAGS -fno-omit-frame-pointer" | sed -e "s/-fomit-frame-pointer//g"`
%endif

# (gb) 1.4.2-2mdk: constants merging causes troubles with long doubles on ia64
%ifarch ia64
OPT_FLAGS="$OPT_FLAGS -fno-merge-constants"
%endif

%ifarch x86_64
OPT_FLAGS="$OPT_FLAGS -fPIC"
%endif

#(tpg) disable all strange flags
#CFLAGS="$OPT_FLAGS" CXXFLAGS="$OPT_FLAGS" \
%configure2_5x --prefix=%{_prefix} \
	--disable-dependency-tracking \
	--enable-cxx \
	--enable-fortran \
	--with-pthread \
	--enable-linux-lfs \
	%ifarch x86_64
	--with-pic \
	%endif
	--enable-production=yes

%make

%check
# all tests must pass on the following architectures
%ifarch %{ix86} x86_64
%make check || echo "make check failed"
%else
%make -k check || echo "make check failed"
%endif

%install
rm -rf %{buildroot}
mkdir -p %{buildroot}%{_libdir}
%makeinstall_std

%multiarch_includes %{buildroot}%{_includedir}/H5pubconf.h

perl -pi -e \
	"s@^libdir=\'/usr/lib\'@libdir=\'%{_libdir}\'@g" %{buildroot}%{_libdir}/*.la

%clean
rm -rf %{buildroot}

%if %mdkversion < 200900
%post -n %{libname} -p /sbin/ldconfig
%endif

%if %mdkversion < 200900
%postun -n %{libname} -p /sbin/ldconfig
%endif

%files
%defattr(-,root,root)
%doc COPYING MANIFEST README.txt release_docs/RELEASE.txt
%{_bindir}/*

%files -n %{libname}
%defattr(-,root,root,755)
%{_libdir}/libhdf5.so.%{major}*
%{_libdir}/libhdf5_cpp.so.%{major}*
%{_libdir}/libhdf5_fortran.so.%{major}*

%files -n %{libname_hl}
%defattr(-,root,root,755)
%{_libdir}/libhdf5_hl.so.%{major_hl}*
%{_libdir}/libhdf5_hl_cpp.so.%{major_hl}*
%{_libdir}/libhdf5hl_fortran.so.%{major_hl}*

%files -n %{develname}
%defattr(-,root,root)
%{_libdir}/*.a
%{_libdir}/*.la
%{_libdir}/*.so
%{_libdir}/*.settings
%{_includedir}/*
%{multiarch_includedir}/H5pubconf.h
%{_datadir}/hdf5_examples/*


%changelog
* Mon May 02 2011 Oden Eriksson <oeriksson@mandriva.com> 1.8.5-2mdv2011.0
+ Revision: 661671
- multiarch fixes

* Fri Aug 13 2010 Emmanuel Andry <eandry@mandriva.org> 1.8.5-1mdv2011.0
+ Revision: 569401
- New version 1.8.5
- drop p?\1952
- rediff p9
- update files list

* Mon Apr 26 2010 Tomasz Pawel Gajc <tpg@mandriva.org> 1.8.4-4mdv2010.1
+ Revision: 539387
- add virtual provides needef for hdf-java

* Mon Apr 26 2010 Tomasz Pawel Gajc <tpg@mandriva.org> 1.8.4-3mdv2010.1
+ Revision: 539340
- update to patch1 postrelease
- disable all strange gcc flags
- spec file clean

* Sun Jan 17 2010 Emmanuel Andry <eandry@mandriva.org> 1.8.4-2mdv2010.1
+ Revision: 492750
- fix linking with p0
- drop p7 fixed upstream
- enable c++ and fortran support
- drop obsolete configure arguments
- use pic for x86_64
- update files list
- remove threadsafe, not compatible with c++

* Thu Jan 07 2010 Emmanuel Andry <eandry@mandriva.org> 1.8.4-1mdv2010.1
+ Revision: 487354
- New version 1.8.4
- fix SOURCE and URL
- drop p1 (merged upstream)
- rediff p2 and p9

* Sat Jul 25 2009 Guillaume Rousse <guillomovitch@mandriva.org> 1.8.3-1mdv2010.0
+ Revision: 399850
- new version

* Thu Apr 09 2009 Funda Wang <fwang@mandriva.org> 1.8.1-3mdv2009.1
+ Revision: 365348
- fix str fmt

* Sun Sep 28 2008 Funda Wang <fwang@mandriva.org> 1.8.1-3mdv2009.0
+ Revision: 288987
- conflicts with old lib

* Sun Sep 28 2008 Funda Wang <fwang@mandriva.org> 1.8.1-2mdv2009.0
+ Revision: 288976
- obsoletes old devel package

* Tue Aug 19 2008 Emmanuel Andry <eandry@mandriva.org> 1.8.1-1mdv2009.0
+ Revision: 274052
- fix typos
- fix file list
- enable parallel build
- define _disable_ld_no_undefined
- enable threadsafe, cxx breaks build
- update file list
- disable P4, use multiarch macro
- use P8 and P6 from opensuse
- add package for high level libraries
- update major
- fix summary
- add fedora patches
- disable threadsafe, incompatible with cxx
- use configure macro
- New version
- drop patches 1,2,3,4 and 5
- use configure2_5x
- Apply devel policy
- protect major

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Mon Dec 17 2007 Thierry Vignaud <tv@mandriva.org> 1.6.5-3mdv2008.1
+ Revision: 126630
- kill re-definition of %%buildroot on Pixel's request


* Tue Feb 20 2007 Giuseppe Ghibò <ghibo@mandriva.com> 1.6.5-3mdv2007.0
+ Revision: 123109
- Enabled threadsafe and pthread.
- Added Patch1 from Debian.
- Merged Patch2,3 from FC6 (rpath, gfortran).
- Merged Patch4 from FC6 (fixes testing problem).
- Merged Patch5 from FC6 (use snprintf instead of sprintf).
- bunzip2 patches.
- Added missed libh5test.so.0 (fix bug #25585)
- Fixed bug #24987.
- Import hdf5

* Fri Sep 01 2006 Giuseppe Ghib <ghibo@mandriva.com> 1.6.5-1mdv2007.0
- Release: 1.6.5.
- Let failed test pass for now.

* Sun Aug 07 2005 Christiaan Welvaart <cjw@daneel.dyndns.org> 1.6.4-2mdk
- -mieee-fp is a x86 specific option

* Sat Aug 06 2005 Giuseppe Ghib <ghibo@mandriva.com> 1.6.4-1mdk
- Release: 1.6.4.
- Lower optimization to -O1 to get tests passing (as were failing with -O2).

* Thu Feb 10 2005 Giuseppe Ghib <ghibo@mandrakesoft.com> 1.6.3-1mdk
- Relase 1.6.3.
- Rediff Patch0.

* Wed Feb 09 2005 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 1.4.5-3mdk
- multiarch

* Sun Oct 03 2004 Giuseppe Ghib <ghibo@mandrakesoft.com> 1.4.5-2mdk
- Don't use %%configure as it doesn't work anymore.
- Rebuilt.

